@@ -61,7 +61,7 @@ usage() {
     echo ""
 }
 
-NVIDIA_BUG_REPORT_CHANGE='$Change: 18542027 $'
+NVIDIA_BUG_REPORT_CHANGE='$Change: 20868374 $'
 NVIDIA_BUG_REPORT_VERSION=`echo "$NVIDIA_BUG_REPORT_CHANGE" | tr -c -d "[:digit:]"`
 
 # Set the default filename so that it won't be empty in the usage message
@@ -523,7 +523,7 @@ append_file_or_dir_silent /usr/share/nvidia/nvidia-application-profiles-*-rc
 
     logfound=0
 
-    for i in /var/log/messages /var/log/kernel.log ; do
+    for i in /var/log/messages /var/log/kernel.log /var/log/dmesg ; do
         if [ -f $i ]; then
             echo ""
             if [ -r $i ]; then
